@@ -7,15 +7,18 @@ using std::vector;
 
 namespace extendedleaps {
 
-class symtwodarray   {	//  Symmetric two dimensional array class. Stores a symmetric matrix of real variables in compact form
+class symtwodarray   {
+/*  Symmetric two dimensional array class. Stores a symmetric matrix of real variables in compact form  */
 	public:
-		explicit symtwodarray(const vind dim);          		//  Constructor
-		symtwodarray(const symtwodarray&);						//  Copy Constructor
-		symtwodarray& operator=(const symtwodarray&);			//  Assignment Operator
-		~symtwodarray(void);                            		//  Destructor 
-		real&  operator() (const vind i,const vind j)			//  Subscripting: reading and writing.  Uses (,) sintaxe starting at (0,0)
+		explicit symtwodarray(const vind dim);          	/*  Constructor  */
+		symtwodarray(const symtwodarray&);			/*  Copy Constructor  */
+		symtwodarray& operator=(const symtwodarray&);		/*  Assignment Operator  */
+		~symtwodarray(void);                            	/*  Destructor  */
+		real&  operator() (const vind i,const vind j)
+/*  Subscripting: reading and writing.  Uses (,) sintaxe starting at (0,0)  */
 		{ if (j<=i) return data[i][j];	else return data[j][i]; }
-		const real  operator() (const vind i,const vind j) const	//  Subscripting: read only. Uses (,) sintaxe starting at (0,0)
+		const real  operator() (const vind i,const vind j) const
+/*  Subscripting: read only. Uses (,) sintaxe starting at (0,0)  */
 		{ if (j<=i) return data[i][j];	else return data[j][i]; }
 	private:
 		vind	dimension;  
@@ -27,19 +30,21 @@ void symatpivot(I&,const real,const symtwodarray&,symtwodarray&,const vind vp,co
 template <class I>
 void vectorpivot(I&,const vector<real>&,vector<real>&,const symtwodarray&,const real,const vind,const vind);
 
-class matvectarray  {	// One dimensional array whose elements can be stored in local memory OR refer to the row of a symmetric matrix
+class matvectarray  {
+/* One dimensional array whose elements can be stored in local memory OR refer to the row of a symmetric matrix  */
 	public:
 		matvectarray(const vind,symtwodarray*,vind const); 
-		void setvalue(const vind j,const real val);		// Writing  own data.
-		const real  operator[] (const vind j) const;	// Subscripting: read only. Uses [] sintaxe starting at [0]  
+		void setvalue(const vind j,const real val);		/* Writing  own data.  */
+		const real  operator[] (const vind j) const;	
+/* Subscripting: read only. Uses [] sintaxe starting at [0]  */
 		void switchtoowndata(void)     {mat = 0; }
 	private:
 		vind		dimension;  
 		symtwodarray*	mat;
 		vind		matrowind;
 		vector<real>	owndata;	
-		matvectarray(const matvectarray&);				//  Forbid copy construction
-		matvectarray& operator=(const matvectarray&);	//  Forbid direct assignment
+		matvectarray(const matvectarray&);		/*  Forbid copy construction  */
+		matvectarray& operator=(const matvectarray&);	/*  Forbid direct assignment  */
 };
 
 template <class I>
@@ -49,7 +54,7 @@ template <class I>
 void symatpivot(I& rowind,const real pivotvalue,const symtwodarray& im,symtwodarray& om,const vind vp,const vind t)
 {
 	I colind(rowind);
-	vind pivotind=rowind[vp-1];                    
+	vind pivotind=rowind[vp-1];
 	real t0=1./pivotvalue,t1;
 
 	rowind.reset(vp);
